@@ -52,7 +52,7 @@ class SubstancesClient(object):
 
     # SUBSTANCES
 
-    def add_substance(self,primary_name,descriptors,source='',other_names=[]):
+    def add_substance(self,name,descriptors={},properties={},documents={},source='',other_names=[]):
         """Add a Substance to the database.
 
         A Substance is defined by a name and a set of descriptors.
@@ -61,15 +61,28 @@ class SubstancesClient(object):
 
         Parameters
         ----------
-        primary_name : str
-            The most appropriate or most recognizable name for the Substance.
-            If this primary name is already assigned 
-            to another Substance in the database,
-            this operation will fail.
+        name : str
+            A name for the Substance.
+            If this name already exists in the database,
+            the add_substance operation will fail.
         descriptors : dict
             Keys are descriptor names, and values are descriptor values.
+            Descriptors are used to encode substances for modeling,
+            so they are expected to be real-valued.
+        properties : dict
+            Keys are property names, and values are property values.
+            This is intended for storing properties 
+            that can be described by a single number,
+            such that these properties can be used for rapid filtering.
+            Properties with complicated structure 
+            (e.g. multiple measurements at different conditions)
+            should be stored in documents.
+        documents : dict
+            Keys are document names, and values are document full texts.
+            This should be used to store any substance data
+            that do not fit neatly as descriptors or properties.
         source : str
-            A representation of the Substance, 
+            A representation of the structure of the Substance,
             sufficient for extracting descriptors.
             For example, a molecule might be represented by a SMILES string,
             and a crystalline solid might be represented by a CIF file.
@@ -88,8 +101,10 @@ class SubstancesClient(object):
             self.service_url+'add_substance', 
             headers={'x-api-key':self.api_key},
             json={
-                'primary_name':primary_name,
+                'name':name,
                 'descriptors':descriptors,
+                'properties':properties,
+                'documents':documents,
                 'source':source,
                 'other_names':other_names
             }
